@@ -184,8 +184,16 @@ cb_html_attrs_as_string (GsfOutput *output, PangoAttribute *a, html_version_t ve
 		break;
 	case PANGO_ATTR_STRIKETHROUGH :
 		if (((PangoAttrInt *)a)->value == 1) {
-			gsf_output_puts (output, "<strike>");
-			closure = "</strike>";
+			if (version == HTML32) {
+				gsf_output_puts (output, "<strike>");
+				closure = "</strike>";
+			} else {
+				gsf_output_puts 
+					(output, 
+					 "<span style=\"text-decoration: "
+					 "line-through;\">");
+				closure = "</span>";
+			}
 		}
 		break;
 	case PANGO_ATTR_UNDERLINE :
@@ -279,7 +287,14 @@ html_write_cell_content (GsfOutput *output, GnmCell *cell, GnmStyle const *style
 				gsf_output_puts (output, "<u>");
 			if (font_is_monospaced (style))
 				gsf_output_puts (output, "<tt>");
-			switch (gnm_style_get_font_strike (style)) {
+			if (gnm_style_get_font_strike (style)) {
+				if (version == HTML32)
+					gsf_output_puts (output, "<strike>");
+				else
+					gsf_output_puts (output, 
+							 "<span style=\"text-decoration: line-through;\">");
+			}
+			switch (gnm_style_get_font_script (style)) {
 			case GO_FONT_SCRIPT_SUB:
 				gsf_output_puts (output, "<sub>");
 				break;
@@ -325,7 +340,13 @@ html_write_cell_content (GsfOutput *output, GnmCell *cell, GnmStyle const *style
 		if (hlink_target)
 			gsf_output_puts (output, "</a>");
 		if (style != NULL) {
-			switch (gnm_style_get_font_strike (style)) {
+			if (gnm_style_get_font_strike (style)) {
+				if (version == HTML32)
+					gsf_output_puts (output, "</strike>");
+				else
+					gsf_output_puts (output, "</span>");
+			}
+			switch (gnm_style_get_font_script (style)) {
 			case GO_FONT_SCRIPT_SUB:
 				gsf_output_puts (output, "</sub>");
 				break;
@@ -641,7 +662,7 @@ html_file_save (GOFileSaver const *fs, GOIOContext *io_context,
 "<html>\n"
 "<head>\n\t<title>Tables</title>\n"
 "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\">\n"
-"\t<!-- \"G_PLUGIN_FOR_HTML\" -->\n"
+"<meta name=\"generator\" content=\"Gnumeric " GNM_VERSION_FULL  " via " G_PLUGIN_FOR_HTML "\">\n"
 "<style><!--\n"
 "tt {\n"
 "\tfont-family: courier;\n"
@@ -664,7 +685,7 @@ html_file_save (GOFileSaver const *fs, GOIOContext *io_context,
 "<html>\n"
 "<head>\n\t<title>Tables</title>\n"
 "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\">\n"
-"\t<!-- \"G_PLUGIN_FOR_HTML\" -->\n"
+"<meta name=\"generator\" content=\"Gnumeric " GNM_VERSION_FULL  " via " G_PLUGIN_FOR_HTML "\">\n"
 "<style type=\"text/css\">\n"
 "tt {\n"
 "\tfont-family: courier;\n"
@@ -687,7 +708,7 @@ html_file_save (GOFileSaver const *fs, GOIOContext *io_context,
 "<html xmlns=\"http://www.w3.org/1999/xhtml\" xml:lang=\"en\" lang=\"en\">\n"
 "<head>\n\t<title>Tables</title>\n"
 "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" />\n"
-"\t<!-- \"G_PLUGIN_FOR_HTML\" -->\n"
+"<meta name=\"generator\" content=\"Gnumeric " GNM_VERSION_FULL  " via " G_PLUGIN_FOR_HTML "\" />\n"
 "<style type=\"text/css\">\n"
 "tt {\n"
 "\tfont-family: courier;\n"
