@@ -65,7 +65,6 @@ typedef struct {
 	GtkWidget           *add_button;
 	GtkWidget           *change_button;
 	GtkWidget           *delete_button;
-	GtkWidget           *model_button;
 	GtkWidget           *scenario_name_entry;
 	struct {
 		GnmExprEntry*entry;
@@ -84,7 +83,8 @@ typedef struct {
 		guint       timer_source;
 		time_t      timer_start;
 		GtkWidget   *status_widget;
-		GtkWidget   *result_widget;
+		GtkWidget   *problem_status_widget;
+		GtkWidget   *objective_value_widget;
 		GtkWidget   *stop_button;
 		GtkWidget   *ok_button;
 		gulong       sig_notify_result, sig_notify_status;
@@ -371,10 +371,10 @@ set_params (Sheet *sheet, GnmSolverParameters *params)
 }
 
 #define GET_BOOL_ENTRY(name_, field_)					\
-do {									\
-	GtkWidget *w_ = glade_xml_get_widget (state->gui, (name_));	\
-	param->field_ = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (w_)); \
-} while (0)
+	do {								\
+		GtkWidget *w_ = glade_xml_get_widget (state->gui, (name_)); \
+		param->field_ = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (w_)); \
+	} while (0)
 
 static void
 extract_settings (SolverState *state)
@@ -555,7 +555,7 @@ cb_notify_result (SolverState *state)
 {
 	GnmSolver *sol = state->run.solver;
 	GnmSolverResult *r;
-	char *txt;
+	const char *txt;
 
 	cb_notify_status (state);
 
@@ -563,36 +563,34 @@ cb_notify_result (SolverState *state)
 	switch (r ? r->quality : GNM_SOLVER_RESULT_NONE) {
 	default:
 	case GNM_SOLVER_RESULT_NONE:
-		txt = g_strdup ("");
+		txt = "";
 		break;
 
-	case GNM_SOLVER_RESULT_FEASIBLE: {
-		char *valtxt = gnm_format_value (go_format_general (),
-						 r->value);
-		txt = g_strdup_printf (_("Feasible: %s"), valtxt);
-		g_free (valtxt);
+	case GNM_SOLVER_RESULT_FEASIBLE:
+		txt = _("Feasible");
 		break;
-	}
 
-	case GNM_SOLVER_RESULT_OPTIMAL: {
-		char *valtxt = gnm_format_value (go_format_general (),
-						 r->value);
-		txt = g_strdup_printf (_("Optimal: %s"), valtxt);
-		g_free (valtxt);
+	case GNM_SOLVER_RESULT_OPTIMAL:
+		txt = _("Optimal");
 		break;
-	}
 
 	case GNM_SOLVER_RESULT_INFEASIBLE:
-		txt = g_strdup (_("Infeasible"));
+		txt = _("Infeasible");
 		break;
 
 	case GNM_SOLVER_RESULT_UNBOUNDED:
-		txt = g_strdup (_("Unbounded"));
+		txt = _("Unbounded");
 		break;
 	}
+	gtk_label_set_text (GTK_LABEL (state->run.problem_status_widget), txt);
 
-	gtk_label_set_text (GTK_LABEL (state->run.result_widget), txt);
-	g_free (txt);
+	if (gnm_solver_has_solution (sol)) {
+		char *valtxt = gnm_format_value (go_format_general (),
+						 r->value);
+		gtk_label_set_text (GTK_LABEL (state->run.objective_value_widget),
+				    valtxt);
+		g_free (valtxt);
+	}
 }
 
 
@@ -617,7 +615,7 @@ static GnmSolverResult *
 run_solver (SolverState *state, GnmSolverParameters *param)
 {
 	GtkDialog *dialog;
-	GtkWidget *hbox;
+	GtkWidget *table;
 	int dialog_res;
 	GError *err = NULL;
 	gboolean ok;
@@ -627,6 +625,7 @@ run_solver (SolverState *state, GnmSolverParameters *param)
 	GnmValue const *vinput;
 	GtkWindow *top = GTK_WINDOW (gtk_widget_get_toplevel (state->dialog));
 	GnmSolverResult *res = NULL;
+	int y;
 
 	sol = param->options.algorithm
 		? gnm_solver_factory_create (param->options.algorithm, param)
@@ -666,21 +665,43 @@ run_solver (SolverState *state, GnmSolverParameters *param)
 					  GTK_STOCK_OK,
 					  GTK_RESPONSE_YES);
 
-	hbox = gtk_hbox_new (FALSE, 2);
+	table = gtk_table_new (4, 2, FALSE);
+	for (y = 0; y < 4; y++) {
+		static const char *ltxt[4] = {
+			N_("Solver Status:"),
+			N_("Problem Status:"),
+			N_("Objective Value:"),
+			N_("Elapsed Time:")
+		};
+		GtkWidget *w, *a;
+		PangoContext *context =
+			gtk_widget_get_pango_context (state->dialog);
 
-	state->run.timer_widget = gtk_label_new ("");
-	gtk_box_pack_start (GTK_BOX (hbox), state->run.timer_widget,
-			    TRUE, TRUE, 0);
+		w = gtk_label_new (_(ltxt[y]));
+		a = gtk_alignment_new (1.0, 0.5, 0.0, 0.0);
+		gtk_container_add (GTK_CONTAINER(a), w);
+		gtk_table_attach_defaults (GTK_TABLE (table),
+					   a, 0, 1, y, y + 1);
+		w = gtk_label_new ("");
+		gtk_widget_ensure_style (w);
+		gtk_widget_set_size_request
+			(w,
+			 go_pango_measure_string (context,
+						  w->style->font_desc,
+						  "0") * (5 + GNM_DIG),
+			 -1);
+		gtk_table_attach_defaults (GTK_TABLE (table),
+					   w, 1, 2, y, y + 1);
+		switch (y) {
+		case 0: state->run.status_widget = w; break;
+		case 1: state->run.problem_status_widget = w; break;
+		case 2: state->run.objective_value_widget = w; break;
+		case 3: state->run.timer_widget = w; break;
+		default: g_assert_not_reached ();
+		}
+	}
 
-	state->run.status_widget = gtk_label_new ("");
-	gtk_box_pack_start (GTK_BOX (hbox), state->run.status_widget,
-			    TRUE, TRUE, 0);
-
-	state->run.result_widget = gtk_label_new ("");
-	gtk_box_pack_start (GTK_BOX (hbox), state->run.result_widget,
-			    TRUE, TRUE, 0);
-
-	gtk_box_pack_start (GTK_BOX (dialog->vbox), hbox, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (dialog->vbox), table, TRUE, TRUE, 0);
 	gtk_widget_show_all (GTK_WIDGET (dialog));
 
 	state->run.sig_notify_result =
@@ -885,6 +906,7 @@ dialog_init (SolverState *state)
 	GSList *cl;
 	GnmCell *target_cell;
 	GnmValue const *input;
+	int i;
 
 	param = state->sheet->solver_parameters;
 
@@ -971,27 +993,26 @@ dialog_init (SolverState *state)
 					NULL);
 	fill_algorithm_combo (state, param->options.model_type);
 
-	state->model_button =
-		glade_xml_get_widget(state->gui, "lp_model_button");
-	g_signal_connect (G_OBJECT (state->model_button), "clicked",
-			  G_CALLBACK (cb_dialog_model_type_clicked), state);
+	for (i = 0; model_type_group[i]; i++) {
+		const char *bname = model_type_group[i];
+		GtkWidget *w = glade_xml_get_widget(state->gui, bname);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w),
+					      param->options.model_type ==
+					      (GnmSolverModelType)i);
+		g_signal_connect (G_OBJECT (w), "clicked",
+				  G_CALLBACK (cb_dialog_model_type_clicked), state);
+	}
 
 	/* Options */
 	state->max_iter_entry = glade_xml_get_widget (state->gui,
 						      "max_iter_entry");
-	{
-		char *txt = g_strdup_printf ("%d", param->options.max_iter);
-		gtk_entry_set_text (GTK_ENTRY (state->max_iter_entry), txt);
-		g_free (txt);
-	}
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (state->max_iter_entry),
+				   param->options.max_iter);
 
 	state->max_time_entry = glade_xml_get_widget (state->gui,
 						      "max_time_entry");
-	{
-		char *txt = g_strdup_printf ("%d", param->options.max_time_sec);
-		gtk_entry_set_text (GTK_ENTRY (state->max_time_entry), txt);
-		g_free (txt);
-	}
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (state->max_time_entry),
+				   param->options.max_time_sec);
 
 /* lhs_entry */
 	table = GTK_TABLE (glade_xml_get_widget (state->gui, "edit-table"));
@@ -1113,12 +1134,6 @@ dialog_init (SolverState *state)
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (
 		glade_xml_get_widget(state->gui, "min_button")),
 			param->problem_type == GNM_SOLVER_MINIMIZE);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (
-		glade_xml_get_widget(state->gui, "lp_model_button")),
-			param->options.model_type == GNM_SOLVER_LP);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (
-		glade_xml_get_widget(state->gui, "qp_model_button")),
-			param->options.model_type == GNM_SOLVER_QP);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (
 		glade_xml_get_widget(state->gui, "no_scenario")),
 			! param->options.add_scenario);
