@@ -224,11 +224,23 @@ gboolean analysis_tool_generic_clean (gpointer specs);
 gboolean analysis_tool_generic_b_clean (gpointer specs);
 
 int analysis_tool_calc_length (analysis_tools_data_generic_t *info);
-void analysis_tools_write_label (GnmValue *val, data_analysis_output_t *dao,
-				 analysis_tools_data_generic_t *info,
-				 int x, int y, int i);
-void analysis_tools_write_label_ftest (GnmValue *val, data_analysis_output_t *dao,
-				       int x, int y, gboolean labels, int i);
+
+void analysis_tools_write_label       (GnmValue *val, /* depreceated */
+				       data_analysis_output_t *dao,
+				       analysis_tools_data_generic_t *info,
+				       int x, int y, int i);
+void analysis_tools_write_label_ftest (GnmValue *val, /* depreceated */
+				       data_analysis_output_t *dao,
+				       int x, int y, 
+				       gboolean labels, int i);
+void analysis_tools_write_a_label     (GnmValue *val, 
+				       data_analysis_output_t *dao,
+				       gboolean   labels, 
+				       group_by_t group_by,
+				       int x, int y);
+void analysis_tools_remove_label      (GnmValue *val,
+				       gboolean labels, 
+				       group_by_t group_by);
 
 gboolean analysis_tool_table (data_analysis_output_t *dao,
 			      analysis_tools_data_generic_t *info,
